@@ -311,6 +311,12 @@ class Extractor:
 
 
     def extract_reference_no(self, text):
+        final_res = {"document_no_full": "",
+                     "document_department_with_tail": None,
+                     "document_department_without_tail": None,
+                     "year": None,
+                     "number": None,
+                     "special": None}
         org_name = None
         year = None
         number = None
@@ -330,20 +336,28 @@ class Extractor:
                     query = query[elem[2]:]
                     break
         if org_name:
-            org_name = utils.max_backward_match_end(org_name, self.keyword)
+            final_res["document_no_full"] += org_name
+            final_res["document_department_without_tail"] = utils.max_backward_match_end(org_name, self.keyword)
 
         res = re.search('[〔\[\(［]?\s*([0-9]{4})\s*[〕\]\)］]?\s*[年]?\s*[第]?\s*([0-9]+)\s*号', query)
         if res:
+            final_res["document_no_full"] += res.group(0)
             year = res.group(1)
             number = res.group(2)
         else:
             res = re.search('[第]?\s*([0-9]+)\s*号[文]?', query)
             if res:
+                final_res["document_no_full"] += res.group(0)
                 number = res.group(1)
         res = re.search('[a-zA-Z]+/[a-zA-Z]+\s*[0-9]+(\.[0-9]+)?[—-][0-9]{4}', query)
         if res:
             another_number = res.group(0)
-        return org_name, year, number, another_number
+            final_res["document_no_full"] += " " + another_number
+        final_res["document_department_with_tail"] = org_name
+        final_res["year"] = year
+        final_res["number"] = number
+        final_res["special"] = another_number
+        return final_res
 
 
 
@@ -403,15 +417,12 @@ class Extractor:
 
 
 
-"""
+
 if __name__ == '__main__':
     et = Extractor()
-    cut_res = list(psg.cut("最热的"))
-    print(et.extract_requirement( cut_res))
-    cut_res = list(psg.cut("5g"))
-    print(et.extract_number(cut_res))
-    res1, res2, res3, res4 = et.extract_reference_no("银监三发")
-    print(res1, res2, res3, res4)
+    res = et.extract_reference_no("JR/T0247—2022/证监会公告〔2022〕30号")
+    print(res)
+    exit(0)
     print(datetime.today())
     start = time.time()
     # text = "2021-03-0914:00开庭审理杨峰？"
@@ -466,4 +477,4 @@ if __name__ == '__main__':
         res = et.extract_time(text, cut_res)
         print(res)
     print((time.time() - start)/len(li))
-"""
+
